//*************************************************************************
//* --------------
//* CDCClusterHist
//* --------------
//* (Description)
//* 	Clasess to create FADC cluster related histograms.
//* (Update Record)
//*	1999/12/06  K.Fujii	Original version.
//*************************************************************************


#include "JSFSteer.h"
#include "CDCClusterHist.h"
#include <iostream.h>

ClassImp(CDCClusterHist)

const Int_t CDCClusterHist::kZoneX   = 2;
const Int_t CDCClusterHist::kZoneY   = 2;
const Int_t CDCClusterHist::kNh = kZoneX*kZoneY;

//___________________________________________________________________________
CDCClusterHist::CDCClusterHist(const Char_t *name, const Char_t *title)
	: JSFModule(name, title)
{
   hdef1 = new THdef1[kNh];
   Char_t st[256], std[256];
   Int_t i;
   for ( i = 0; i < kNh; i++ ) {
      sprintf(st,"CDCClusterHist.hPh%2.2d",i);
      sprintf(std,"Ph for pad %2.2d, 256, 0.0, 256.0",i);
      sscanf(gJSF->Env()->GetValue(st,std),"%s %d,%g,%g",hdef1[i].title,
	  		&hdef1[i].nbin, &hdef1[i].xmin, &hdef1[i].xmax);
   }
   hPh = new TH1F* [kNh];
}

//___________________________________________________________________________
CDCClusterHist::~CDCClusterHist()
{
   delete hdef1;
   for (Int_t i = 0; i < kNh; i++ ) delete hPh[i];
   delete hPh; 
}

//___________________________________________________________________________
Bool_t CDCClusterHist::Initialize()
{
   TDirectory *last=gDirectory;
   gFile->cd("/");
   Int_t i;
   for ( i = 0; i < kNh; i++ ) {
      hPh[i] = new TH1F(hdef1[i].title,hdef1[i].title, hdef1[i].nbin,
    		        hdef1[i].xmin,hdef1[i].xmax);
      cout << i << " " << hdef1[i].title 
      		<< " n " << hdef1[i].nbin
      		<< " xmin " << hdef1[i].xmin
      		<< " xmax " << hdef1[i].xmax << endl;
   }
   hc1=new TCanvas("hc1","Canvas 1",20, 20, 300*kZoneX, 300*kZoneY);
   hc1->Divide(kZoneX,kZoneY);
   last->cd();
   return kTRUE;
}


//___________________________________________________________________________
Bool_t CDCClusterHist::Process(Int_t ev)
{
   TDirectory *last = gDirectory;
   gFile->cd("/");

   CDCClusterMaker *cm  = (CDCClusterMaker*)gJSF->FindModule("CDCClusterMaker");
   CDCClusterBuf   *clb = (CDCClusterBuf *)cm->EventBuf();
   TObjArray *clsp = clb->GetClusters();
   TIter next(clsp);
   CDCCluster *clp;
   while ((clp = (CDCCluster *)next())) {
#if 0
      Int_t    n    = clp->GetStationNo();
      Double_t tim  = clp->GetStartTime();
#endif
      Int_t    a    = clp->GetChannelNo();
      // Double_t adc  = clp->GetPeak();
      Double_t adc  = clp->GetSum();
#if 0
      cerr << n << " " << a << " " << adc << " " << tim << endl;
#endif
      if ( a < CDCClusterHist::kNh ) hPh[a]->Fill(adc);
   }
   Draw();
   last->cd();
   return kTRUE;
}

//___________________________________________________________________________
void CDCClusterHist::Draw(Option_t *opt)
{
   TDirectory *last = gDirectory;
   gFile->cd("/");
   Int_t i;
   for( i = 0; i < CDCClusterHist::kNh; i++ ) {
      hc1->cd(i+1);
      hPh[i]->Draw();
      hc1->Update();
   }
   last->cd();
}

