//*************************************************************************
//* --------------
//* CDCPadHist
//* --------------
//* (Description)
//* 	Clasess to create pad hit related histograms.
//* (Update Record)
//*	1999/12/06  K.Hoshina 		original version
//*************************************************************************


#include "JSFSteer.h"
#include "CDCPadHist.h"
#include <iostream.h>

ClassImp(CDCPadHist)

const Int_t CDCPadHist::kZoneX   = 2;
const Int_t CDCPadHist::kZoneY   = 2;
const Int_t CDCPadHist::kNh = 3;

//___________________________________________________________________________
CDCPadHist::CDCPadHist(const Char_t *name, const Char_t *title)
	: JSFModule(name, title)
{
   hdef2 = new THdef2[kNh];
   Char_t st[256], std[256];
   Int_t i = 0;
   sprintf(st,"CDCPadHist.hG01");
   sprintf(std,"G1, 300, 0.0, 300.0, 300, -3.0, 3.0");
   sscanf(gJSF->Env()->GetValue(st,std),"%s %d,%g,%g,%d,%g,%g",
   			hdef2[i].title,
	  		&hdef2[i].nxbin, &hdef2[i].xmin, &hdef2[i].xmax,
	  		&hdef2[i].nybin, &hdef2[i].ymin, &hdef2[i].ymax);
   i++;
   sprintf(st,"CDCPadHist.hG02");
   sprintf(std,"G2, 300, 0.0, 300.0, 300, -3.0, 3.0");
   sscanf(gJSF->Env()->GetValue(st,std),"%s %d,%g,%g,%d,%g,%g",
   			hdef2[i].title,
	  		&hdef2[i].nxbin, &hdef2[i].xmin, &hdef2[i].xmax,
	  		&hdef2[i].nybin, &hdef2[i].ymin, &hdef2[i].ymax);
   i++;
   sprintf(st,"CDCPadHist.hGdiff");
   sprintf(std,"DG, 300, 0.0, 300.0, 300, -3.0, 3.0");
   sscanf(gJSF->Env()->GetValue(st,std),"%s %d,%g,%g,%d,%g,%g",
   			hdef2[i].title,
	  		&hdef2[i].nxbin, &hdef2[i].xmin, &hdef2[i].xmax,
	  		&hdef2[i].nybin, &hdef2[i].ymin, &hdef2[i].ymax);
   hG = new TH2F* [kNh];
}

//___________________________________________________________________________
CDCPadHist::~CDCPadHist()
{
   delete hdef2;
   for (Int_t i = 0; i < kNh; i++ ) delete hG[i];
   delete hG; 
}

//___________________________________________________________________________
Bool_t CDCPadHist::Initialize()
{
   TDirectory *last=gDirectory;
   gFile->cd("/");
   Int_t i;
   for ( i = 0; i < kNh; i++ ) {
      hG[i] = new TH2F(hdef2[i].title,hdef2[i].title, 
      			hdef2[i].nxbin,hdef2[i].xmin,hdef2[i].xmax,
      			hdef2[i].nybin,hdef2[i].ymin,hdef2[i].ymax);
      cout << i << " " << hdef2[i].title 
      		<< " nx " << hdef2[i].nxbin
      		<< " xmin " << hdef2[i].xmin
      		<< " xmax " << hdef2[i].xmax 
      		<< " ny " << hdef2[i].nybin
      		<< " ymin " << hdef2[i].ymin
      		<< " ymax " << hdef2[i].ymax       		
      		<< endl;
   }     		
   hc1=new TCanvas("hc1","Canvas 1",20, 20, 300*kZoneX, 300*kZoneY);
   hc1->Divide(kZoneX,kZoneY);
   last->cd();
   return kTRUE;
}


//___________________________________________________________________________
Bool_t CDCPadHist::Process(Int_t ev)
{
   TDirectory *last = gDirectory;
   gFile->cd("/");

   CDCPadHitMaker *hm  = (CDCPadHitMaker*)gJSF->FindModule("CDCPadHitMaker");
   CDCPadHitBuf   *hb = (CDCPadHitBuf *)hm->EventBuf();
   TObjArray *hsp = hb->GetHits();
   if (hsp->GetEntries() != 2) return kFALSE;
   CDCPadHit *h1p = (CDCPadHit *)hsp->At(0);
   CDCPadHit *h2p = (CDCPadHit *)hsp->At(1);
   Double_t g1 = h1p->X();
   Double_t g2 = h2p->X();
   Double_t gdiff = g1-g2;
   Int_t nevt = gJSF->GetEventNumber();
      
   hG[0]->Fill(nevt,g1,1.0);
   hG[1]->Fill(nevt,g2,1.0);
   hG[2]->Fill(nevt,gdiff,1.0);
   Draw();
   last->cd();
   return kTRUE;
}

//___________________________________________________________________________
void CDCPadHist::Draw(Option_t *opt)
{
   TDirectory *last = gDirectory;
   gFile->cd("/");
   Int_t i;
   for( i = 0; i < CDCPadHist::kNh; i++ ) {
      hc1->cd(i+1);
      hG[i]->Draw();
      hc1->Update();
   }
   last->cd();
}




