//*************************************************************************
//* --------------------
//* CDCRawADCDatum Class
//* --------------------
//* (Description)
//* 	Classes for a single FADC datum.
//* (Requires)
//*	TObject
//* (Provides)
//*	CDCRawADCDatum
//* (Update Record)
//*	1999/06/02  K.Fujii	Original version.
//*
//*************************************************************************


#include "JSFSteer.h"
#include "CDCRawADCDatum.h"
#include <iostream.h>

ClassImp(CDCRawADCDatum)

// static variables are not declared as constant so as to allow
// different formats in future.

Int_t CDCRawADCDatum::gFormatID = 0;	// Format ID
Int_t CDCRawADCDatum::gNstabits = 0;	// No. station number bits
Int_t CDCRawADCDatum::gNchabits = 3;	// No. channel number bits
Int_t CDCRawADCDatum::gNswperdt = 2;	// No. short words per FADC datum

//___________________________________________________________________________
// ------------
// Constructors
// ------------
//
CDCRawADCDatum::CDCRawADCDatum() 
	: fStationNo(0), fChannelNo(0), fADC(0), fTime(0) {}
//___________________________________________________________________________
CDCRawADCDatum::CDCRawADCDatum(CDCRawADCDatum & rad) 
{
    fStationNo 	= rad.fStationNo;
    fChannelNo 	= rad.fChannelNo;
    fADC	= rad.fADC;
    fTime	= rad.fTime;
}

//___________________________________________________________________________
CDCRawADCDatum::CDCRawADCDatum(ADC_t adcword[])
{
    Unpack(adcword);
}

//___________________________________________________________________________
// ------------
// Destructors
// ------------
//
CDCRawADCDatum::~CDCRawADCDatum() {}

//___________________________________________________________________________
// -------
// Setters
// -------
//
// This methods should be modified according to your raw data format.
//
void CDCRawADCDatum::SetFormat(CDCUniversalRecordHeader & urh)
{ 
    gFormatID = urh.GetFormatID();
    // set gNstabits, etc., according to the format ID.
    switch (gFormatID) {
    	case 0: {
            gNstabits = 0;
            gNchabits = 3;
            break;
        }
        default: { 
            cerr << "Format ID = " << gFormatID
                 << " is not supported" << endl;
        }
    }
}

//___________________________________________________________________________
// ---------------
// Service Methods
// ---------------
//
// This methods should be modified according to your raw data format.
//
void CDCRawADCDatum::Unpack(ADC_t adcword[])
{
#ifndef LITTLE_ENDIAN
        adcword[0] = (adcword[0] << 8) | (adcword[0] >> 8);
        adcword[1] = (adcword[1] << 8) | (adcword[1] >> 8);
#endif
  	fStationNo = 0;
  	fChannelNo = (adcword[0] >> (sizeof(ADC_t)*8 - gNchabits)) - 1;
  	fTime	   = adcword[0] & ( 0xffff >> gNchabits );
  	fADC	   = adcword[1];
}

//___________________________________________________________________________
void CDCRawADCDatum::DebugPrint()
{
    cerr << " n " << fStationNo
         << " a " << fChannelNo
         << " adc " << fADC
         << " tim " << fTime << endl;
}
