//*************************************************************************
//* ----------
//* CDCRawHist
//* ----------
//* (Description)
//*	This set of classes serves for CDC raw data analysis.
//*
//*	The following parameters can be specified in "jsf.conf". 
//*
//*	    CDCRawData.RFNFormat:       printf format to construct file name
//*	    CDCRawData.DoPlots:         (TRUE/FASLE)
//*         CDCRawHist.hPhii:           Phii 256.0, 0.0, 256.0
//*
//* (Update Record)
//*	1999/06/05  K.Fujii	Original version.
//*
//*************************************************************************


#include "JSFSteer.h"
#include "CDCRawHist.h"
#include <iostream.h>

ClassImp(CDCRawHist)

const Int_t CDCRawHist::kZoneX   = 2;
const Int_t CDCRawHist::kZoneY   = 2;
const Int_t CDCRawHist::kNh = kZoneX*kZoneY;

//___________________________________________________________________________
CDCRawHist::CDCRawHist(const Char_t *name, const Char_t *title)
	: JSFModule(name, title)
{
   hdef1 = new THdef1[kNh];
   Char_t st[256], std[256];
   Int_t i;
   for ( i = 0; i < kNh; i++ ) {
      sprintf(st,"CDCRawHist.hPh%2.2d",i);
      sprintf(std,"Ph for pad %2.2d, 256, 0.0, 256.0",i);
      sscanf(gJSF->Env()->GetValue(st,std),"%s %d,%g,%g",hdef1[i].title,
	  		&hdef1[i].nbin, &hdef1[i].xmin, &hdef1[i].xmax);
   }
   hPh = new TH1F* [kNh];
}

//___________________________________________________________________________
CDCRawHist::~CDCRawHist()
{
   delete hdef1;
   for (Int_t i = 0; i < kNh; i++ ) delete hPh[i];
   delete hPh; 
}

//___________________________________________________________________________
Bool_t CDCRawHist::Initialize()
{
   TDirectory *last=gDirectory;
   gFile->cd("/");
   Int_t i;
   for ( i = 0; i < kNh; i++ ) {
      hPh[i] = new TH1F(hdef1[i].title,hdef1[i].title, hdef1[i].nbin,
    		        hdef1[i].xmin,hdef1[i].xmax);
      cout << i << " " << hdef1[i].title 
      		<< " n " << hdef1[i].nbin
      		<< " xmin " << hdef1[i].xmin
      		<< " xmax " << hdef1[i].xmax << endl;
   }
   hc1=new TCanvas("hc1","Canvas 1",20, 20, 300*kZoneX, 300*kZoneY);
   hc1->Divide(kZoneX,kZoneY);
   last->cd();
   return kTRUE;
}


//___________________________________________________________________________
Bool_t CDCRawHist::Process(Int_t ev)
{
   TDirectory *last = gDirectory;
   gFile->cd("/");

   CDCRawData    *raw = (CDCRawData*)gJSF->FindModule("CDCRawData");
   CDCRawDataBuf *evt = (CDCRawDataBuf *)raw->EventBuf();
   Int_t ncdc = evt->GetNADCData();
   cerr << " ncdc = " << ncdc << endl;
   TClonesArray *adcdata = evt->GetADCData();
   Int_t i;
   for ( i = 0; i < ncdc; i++ ) {
      CDCRawADCDatum *adcdatum = (CDCRawADCDatum *)adcdata->UncheckedAt(i);
#if 0
      Int_t n    = adcdatum->GetStationNo();
      Int_t tim  = adcdatum->GetTime();
#endif
      Int_t a    = adcdatum->GetChannelNo();
      Int_t adc  = adcdatum->GetADC();
#if 0
      cerr << n << " " << a << " " << adc << " " << tim << endl;
#endif
      if ( a < CDCRawHist::kNh ) hPh[a]->Fill(adc);
   }
   Draw();
   last->cd();
   return kTRUE;
}

//___________________________________________________________________________
void CDCRawHist::Draw(Option_t *opt)
{
   TDirectory *last = gDirectory;
   gFile->cd("/");
   Int_t i;
   for( i = 0; i < CDCRawHist::kNh; i++ ) {
      hc1->cd(i+1);
      hPh[i]->Draw();
      hc1->Update();
   }
   last->cd();
}
