//*************************************************************************
//* ------------------------------
//* CDCUniversalRecordHeader Class
//* ------------------------------
//* (Description)
//*	This class contains the header information that all the
//*	CDC raw records carry in common.
//* (Requires)
//*	TObject
//* (Provides)
//*	CDCUniversalRecordHeader	: universal record header
//* (Update Record)
//*	1999/06/02  K.Fujii	Original version.
//*
//*************************************************************************

#include "JSFSteer.h"
#include "CDCUniversalRecordHeader.h"
#include <iostream.h>

ClassImp(CDCUniversalRecordHeader)

//
// gNElms: No. elements in URH excluding the 1st "NWORDS" word.
//
Len_t CDCUniversalRecordHeader::gNElms     = 3;
Len_t CDCUniversalRecordHeader::gLElms     = gNElms * sizeof(URH_t)/2;
Len_t CDCUniversalRecordHeader::gURHLength = gLElms + sizeof(Len_t)/2;

//___________________________________________________________________________
CDCUniversalRecordHeader::CDCUniversalRecordHeader() 
  	: fBufferLength(0), fFormatID(0), fRecordType(0), 
  	  fRunNumber(0), fEventNumber(0) {}

//___________________________________________________________________________
CDCUniversalRecordHeader::~CDCUniversalRecordHeader() {}


//___________________________________________________________________________
Bool_t CDCUniversalRecordHeader::ReadFile(FILE *fd) 
{
#ifndef LITTLE_ENDIAN
    UShort_t dum[2];
    Len_t ne = fread(dum, sizeof(Len_t), 1, fd);
    dum[0] = (dum[0] << 8) | (dum[0] >> 8);
    dum[1] = (dum[1] << 8) | (dum[1] >> 8);
    UInt_t dum4 = dum[1];
    fBufferLength = (dum4 << 16) | dum[0];
#else
    Len_t ne = fread(&fBufferLength, sizeof(Len_t), 1, fd);
#endif
    if ( ne != 1 || fBufferLength <= 0 ) {
        Error("UniversalRecordHeader","Failed to read Buffer Length.");
        fRecordType = -9999;
        return kFALSE;
    }
    URH_t *hd = new URH_t[gNElms];
    ne = fread(hd, sizeof(URH_t), gNElms, fd);
    if ( ne != gNElms ) {
       Error("UniversalRecordHeader","Failed to read URH.");
       delete hd;
       return kFALSE;
    }
    Unpack(hd);
    delete hd;
    return kTRUE;
}

//___________________________________________________________________________
void CDCUniversalRecordHeader::Unpack(URH_t hd[])
{
#ifndef LITTLE_ENDIAN
    for (Int_t i = 0; i < gLElms; i++) {
        hd[i] = (hd[i] << 8) | (hd[i] >> 8);
    }
#endif
    switch (fFormatID) {
    	case 0: {
            fRunNumber   = hd[0];
            fEventNumber = hd[1];
            fRecordType  = (SURH_t)hd[2];
            
            break;
        }
        default: { 
            cerr << "Format ID = " << fFormatID
                 << " is not supported" << endl;
        }
    }
    if (fRecordType == kRecTypeBRR) gJSF->SetRunNumber(fRunNumber);
    gJSF->SetEventNumber(fEventNumber);
}

//___________________________________________________________________________
void CDCUniversalRecordHeader::DebugPrint()
{
    cerr << " No. words = "  << fBufferLength
         << " Format = "     << fFormatID
         << " Record ID = "  << fRecordType
         << " Run = "        << fRunNumber
         << " Event = "      << fEventNumber << endl;
}
