#ifndef __CDCUNIVERSALRECORDHEADER__
#define __CDCUNIVERSALRECORDHEADER__

//*************************************************************************
//* ------------------------------
//* CDCUniversalRecordHeader Class
//* ------------------------------
//* (Description)
//*	This class contains the header information that all the
//*	CDC raw records carry in common.
//* (Requires)
//*	TObject
//* (Provides)
//*	CDCUniversalRecordHeader	: universal record header
//* (Update Record)
//*	1999/06/02  K.Fujii	Original version.
//*************************************************************************

#include "TObject.h"
#include "TDatime.h"

#include "JSFModule.h"

#include "CDCTypeDef.h"

// -----------------------
// Universal Record Header
// -----------------------

static  const Int_t kRecTypeField =  4;
static  const Int_t kRecTypeBRR   =  1;
static  const Int_t kRecTypeERR   =  2;
static  const Int_t kRecTypeADC   = 10;

class CDCUniversalRecordHeader : public TObject {
private:
  Len_t   fBufferLength;	//  Buffer length in units of 2byes
  URH_t   fFormatID;		//  Format ID
  SURH_t  fRecordType;		//  Record type
  URH_t   fRunNumber;		//  Run number
  URH_t   fEventNumber;		//  Event number
  static  Len_t gNElms;		//! No. of elements in URH
  static  Len_t gLElms;		//! No. of words for elements in URH
  static  Len_t gURHLength;	//! No. of words for URH

public:
  CDCUniversalRecordHeader();
  virtual ~CDCUniversalRecordHeader();

  Bool_t	ReadFile(FILE *fd);
  void		Unpack(URH_t hd[]);
  void		DebugPrint();

  inline Len_t  GetBufferLength() const { return fBufferLength;              }
  inline Len_t  GetDataLength  () const { return (fBufferLength-gURHLength); }
  inline Int_t  GetFormatID    () const { return fFormatID;                  }
  inline Int_t  GetRecordType  () const { return fRecordType;                }
  inline Int_t  GetRunNumber   () const { return fRunNumber;                 }
  inline Int_t  GetEventNumber () const { return fEventNumber;               }

  ClassDef(CDCUniversalRecordHeader,1) // CDC Universal Record Header
};

#endif
